@@ -4,12 +4,12 @@
 #' @noRd
 md2ast <- function(x,
                    pandoc_args = NULL,
-                   .from = "markdown",
-                   yaml = rmarkdown::metadata) {
+                   metadata = rmarkdown::metadata,
+                   .from = "markdown") {
   tf <- tempfile()
 
-  front_matter <- if ((length(yaml) > 0) && support_yaml(.from)) {
-    yaml::write_yaml(yaml, tf)
+  front_matter <- if ((length(metadata) > 0) && support_yaml(.from)) {
+    yaml::write_yaml(metadata, tf)
     c("---", xfun::read_utf8(tf), "---", "", "")
   }
 
@@ -20,7 +20,7 @@ md2ast <- function(x,
     to = "json",
     from = .from,
     output = tf,
-    citeproc = !is.null(yaml$bibliography) || any(grepl("^--bibliography", pandoc_args)),
+    citeproc = !is.null(metadata[["bibliography"]]) || any(grepl("^--bibliography", pandoc_args)),
     options = pandoc_args,
     wd = getwd()
   )
